import { ACTOR_JOB_STATUSES } from '@apify/consts';
import { Args, Flags } from '@oclif/core';
import { ApifyCommand } from '../../lib/apify_command.js';
import { error, success } from '../../lib/outputs.js';
import { getLoggedClientOrThrow } from '../../lib/utils.js';
const runningStatuses = [ACTOR_JOB_STATUSES.READY, ACTOR_JOB_STATUSES.RUNNING];
const abortingStatuses = [ACTOR_JOB_STATUSES.ABORTING, ACTOR_JOB_STATUSES.TIMING_OUT];
export class RunsAbortCommand extends ApifyCommand {
    async run() {
        const { runId } = this.args;
        const apifyClient = await getLoggedClientOrThrow();
        const run = await apifyClient.run(runId).get();
        if (!run) {
            error({ message: `Run with ID "${runId}" was not found on your account.` });
            return;
        }
        if (!runningStatuses.includes(run.status)) {
            if (abortingStatuses.includes(run.status)) {
                error({ message: `Run with ID "${runId}" is already aborting.` });
            }
            else {
                error({ message: `Run with ID "${runId}" is already aborted.` });
            }
            return;
        }
        try {
            const result = await apifyClient.run(runId).abort({ gracefully: !this.flags.force });
            if (this.flags.json) {
                return result;
            }
            if (this.flags.force) {
                success({ message: `Triggered the immediate abort of run "${runId}".` });
            }
            else {
                success({
                    message: `Triggered the abort of run "${runId}", it should finish aborting in up to 30 seconds.`,
                });
            }
        }
        catch (err) {
            const casted = err;
            error({
                message: `Failed to abort run "${runId}".\n  ${casted.message || casted}`,
            });
        }
        return undefined;
    }
}
Object.defineProperty(RunsAbortCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: 'Aborts an Actor Run.'
});
Object.defineProperty(RunsAbortCommand, "args", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        runId: Args.string({
            required: true,
            description: 'The run ID to abort.',
        }),
    }
});
Object.defineProperty(RunsAbortCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        force: Flags.boolean({
            description: 'Whether to force the run to abort immediately, instead of gracefully.',
            default: false,
            char: 'f',
        }),
    }
});
Object.defineProperty(RunsAbortCommand, "enableJsonFlag", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: true
});
//# sourceMappingURL=abort.js.map